@@ -28,7 +28,7 @@ use Ref::Util qw(
 );
 use Carp 'croak';
 
-our $VERSION = '0.31';
+our $VERSION = '0.32';
 
 our @EXPORT_OK = qw(
   _assert_import_list_is_valid
@@ -75,6 +75,12 @@ sub _our_import {
 sub _assert_import_list_is_valid {
     my ( $class, $args ) = @_;
 
+    foreach my $features (qw/types includes excludes/) {
+        if ( exists $args->{$features} && !ref $args->{$features} ) {
+            $args->{$features} = [ $args->{$features} ];
+        }
+    }
+
     $args->{call_level} //= 0;
     my ( $package, $filename, $line ) = caller( $args->{call_level} + 1 );
     my $target_class = $args->{for_class} // $package;
@@ -260,10 +266,10 @@ sub param ( $meta, $name, %opt_for ) {
     # "has [@attributes]" versus "has $attribute"
     foreach my $attr ( is_plain_arrayref($name) ? @$name : $name ) {
         my %options = %opt_for;    # copy each time to avoid overwriting
-        unless ( $options{init_arg} ) {
-            $attr =~ s/^\+//;      # in case they're overriding a parent class attribute
-            $options{init_arg} //= $attr;
-        }
+        $options{init_arg} //= $attr;
+
+        # in case they're inheriting an attribute
+        $options{init_arg} =~ s/\A\+//;
         _add_attribute( 'param', $meta, $attr, %options );
     }
 }
@@ -296,10 +302,17 @@ sub field ( $meta, $name, %opt_for ) {
 sub _add_attribute ( $attr_type, $meta, $name, %opt_for ) {
     _debug("Finalizing options for '$attr_type $name'");
 
+    # we use the $name to generate the other methods names. However,
+    # $orig_name is used to set the actual field name. This is because
+    # Moose allows `has '+x' => ( writer => 'set_x' );` to inherit an
+    # attribute from a parent class and only change the desired attribute
+    # options.
+    my $orig_name = $name;
+    $name =~ s/\A\+//;
     unless ( _is_valid_method_name($name) ) {
         throw_exception(
             'InvalidAttributeDefinition',
-            attribute_name => $name,
+            attribute_name => $orig_name,
             class_name     => $meta->name,
             messsage       => "Illegal attribute name, '$name'",
         );
@@ -332,9 +345,9 @@ sub _add_attribute ( $attr_type, $meta, $name, %opt_for ) {
         unless ( _is_valid_method_name( $opt_for{$option} ) ) {
             throw_exception(
                 'InvalidAttributeDefinition',
-                attribute_name => $name,
+                attribute_name => $orig_name,
                 class_name     => $meta->name,
-                messsage       => "Attribute '$name' has an invalid option name, $option => '$opt_for{$option}'",
+                messsage       => "Attribute '$orig_name' has an invalid option name, $option => '$opt_for{$option}'",
             );
         }
     }
@@ -365,8 +378,8 @@ sub _add_attribute ( $attr_type, $meta, $name, %opt_for ) {
     }
 
     delete $opt_for{_call_level};
-    _debug( "Setting $attr_type, '$name'", \%opt_for );
-    $meta->add_attribute( $name, %opt_for );
+    _debug( "Setting $attr_type, '$orig_name'", \%opt_for );
+    $meta->add_attribute( $orig_name, %opt_for );
 }
 
 sub _is_valid_method_name ($name) {
@@ -496,7 +509,7 @@ MooseX::Extended::Core - Internal module for MooseX::Extended
 
 =head1 VERSION
 
-version 0.31
+version 0.32
 
 =head1 DESCRIPTION
 
